<?php

if ( ! isset( $content_width ) )
	$content_width = 578;

add_action( 'after_setup_theme', 'luxury_setup' );

if ( ! function_exists( 'luxury_setup' ) ) :

function luxury_setup() {

	require( get_template_directory() . '/inc/theme-options.php' );

	$default_background_color = '111111';

	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'custom-background', array( 'default-color' => $default_background_color ) );

	$custom_header_support = array(
		'default-text-color' => '222',
		'width' => '618',
		'height' => '100',
		'flex-height' => true,
		'admin-head-callback' => 'luxury_admin_header_style',
		'wp-head-callback' => 'luxury_header_style'
		);

	add_theme_support( 'custom-header', $custom_header_support );

	add_editor_style();

	set_post_thumbnail_size( 552, 125, true );

}
endif;

if ( ! function_exists( 'luxury_admin_header_style' ) ) :

function luxury_admin_header_style() {
?>
	<link href='http://fonts.googleapis.com/css?family=Dancing+Script:700' rel='stylesheet' type='text/css' />
	<link href='http://fonts.googleapis.com/css?family=Lato:400' rel='stylesheet' type='text/css' />
	<style type="text/css">
	.appearance_page_custom-header #headimg {
		background: #<?php background_color(); ?> url('<?php background_image(); ?>');
		border: none;
	}
	#headimg h1 {
		color: #ddd;
		font: normal 40px 'Dancing Script', Helvetica, cursive;
		margin-left: 5px;
	}
	#headimg h1 a {
		text-decoration: none;
	}
	#desc {
		color: #ddd;
		font: italic 16px 'Lato', Helvetica, sans-serif;
		margin-left: 5px;
	}
	</style>
<?php
}
endif;

if ( ! function_exists( 'luxury_header_style' ) ) :

function luxury_header_style() {
	$text_color = get_header_textcolor();

	if ( $text_color == HEADER_TEXTCOLOR )
		return;
?>
<style type="text/css">
<?php
	if ( 'blank' == $text_color ) :
?>
	#site-title,
	#site-description {
		position: absolute !important;
		clip: rect( 1px 1px 1px 1px);
		clip: rect( 1px, 1px, 1px, 1px);
	}
<?php
	else :
?>
	#site-title a,
	#site-description {
		color: #<?php echo $text_color; ?> !important;
	}
	<?php endif; ?>
	</style>
<?php
}
endif;

add_action( 'wp_enqueue_scripts', 'luxury_stylesheet' );
function luxury_stylesheet() {
	wp_register_style( 'luxury', get_template_directory_uri() . '/style.css' );
	wp_enqueue_style( 'luxury' );
}

add_action( 'wp_head', 'luxury_googlefonts' );
function luxury_googlefonts() {
	echo "<link href='http://fonts.googleapis.com/css?family=Dancing+Script:700' rel='stylesheet' type='text/css' />
		<link href='http://fonts.googleapis.com/css?family=Lato:400' rel='stylesheet' type='text/css' />";
}

add_action( 'admin_enqueue_scripts', 'luxury_admin_fonts' );
function luxury_admin_fonts() { ?>		
	<link href='http://fonts.googleapis.com/css?family=Dancing+Script:700' rel='stylesheet' type='text/css' />
	<link href='http://fonts.googleapis.com/css?family=Lato:400' rel='stylesheet' type='text/css' />
<?php
}

add_action( 'widgets_init', 'luxury_register_sidebar' );
function luxury_register_sidebar() {
	register_sidebar(
		array(
			'id' => 'primary',
			'name' => 'Main Sidebar',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<p class="widget-title">',
			'after_title' => '</p>'
		)
	);
}

function luxury_comments( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	?>
	<!-- Begin comment -->
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<div id="comment-<?php comment_ID(); ?>" class="comment">
			<div class="comment-author vcard">
				<?php echo get_avatar( $comment, $size='60' );
					echo '<p class="comment-author-link">';
					printf( __( '%1$s', 'luxury' ), get_comment_author_link() );
					echo '</p>';
					echo '<p class="comment-author-meta">';
					printf( __( '%1$s | %2$s' ), get_comment_date( ' n/j/Y' ), get_comment_time() ); ?>
					<a href="<?php the_permalink(); echo "#li-comment-"; comment_ID(); ?>">Permalink</a>
					<?php if ( current_user_can( 'edit_comment' ) )
					edit_comment_link( 'Edit Comment', '| ' ); ?>
					</p>
			</div>
			<?php comment_text(); ?>
			<!-- Start comment reply link -->
			<p class="comment-reply">
				<?php 
				if ( !comments_open() ) : else :
				comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Respond to this comment', 'luxury' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) );
				endif;
				?>
			</p>
		</div>
<?php

}

/* End Comment Template Styling */

function luxury_pingback_trackback( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	if ( $comment->comment_type == 'pingback' ) { ?>
		<li class="ping">
			<?php comment_author_link();
				comment_text();
	} elseif ( $comment->comment_type == 'trackback' ) { ?>
		<li class="track">
			<?php comment_author_link();
				comment_text();
	}
}

/* Comment Form Styling */

function luxury_comment_form( $args = array(), $post_id = null ) {
	global $user_identity, $id;

	if ( null === $post_id )
		$post_id = $id;
	else
		$id = $post_id;

	$commenter = wp_get_current_commenter();

	$req = get_option( 'require_name_email' );
	$aria_req = ( $req ? " aria-required='true'" : '' );
	$fields =  array(
		'author' => '<p class="comment-form-author">' . '<label for="author">' . __( 'Name', 'luxury' ) . '</label> ' . ( $req ? '<span class="required">*</span>' : '' ) .
		            '<br /><input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30"' . $aria_req . ' /></p>',
		'email'  => '<p class="comment-form-email"><label for="email">' . __( 'Email', 'luxury' ) . '</label> ' . ( $req ? '<span class="required">*</span>' : '' ) .
		            '<br /><input id="email" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30"' . $aria_req . ' /></p>',
		'url'    => '<p class="comment-form-url"><label for="url">' . __( 'Website', 'luxury' ) . '</label>' .
		            '<br /><input id="url" name="url" type="text" value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="30" /></p>',
	);

	$required_text = sprintf( ' ' . __('Required fields are marked %s', 'luxury'), '<span class="required">*</span>' );
	$defaults = array(
		'fields'               => apply_filters( 'comment_form_default_fields', $fields ),
		'comment_field'        => '<p class="comment-form-comment"><label for="comment">' . _x( 'Comment', 'noun', 'luxury' ) . '</label><br /><textarea id="comment" name="comment" cols="57" rows="12" aria-required="true"></textarea></p>',
		'must_log_in'          => '<p class="must-log-in">' .  sprintf( __( 'You must be <a href="%s">logged in</a> to post a comment.' ), wp_login_url( apply_filters( 'the_permalink', get_permalink( $post_id ) ) ) ) . '</p>',
		'logged_in_as'         => '<p class="logged-in-as">' . sprintf( __( 'Logged in as <a href="%1$s">%2$s</a>. <a href="%3$s" title="Log out of this account">Log out?</a>' ), admin_url( 'profile.php' ), $user_identity, wp_logout_url( apply_filters( 'the_permalink', get_permalink( $post_id ) ) ) ) . '</p>',
		'comment_notes_before' => '<p class="comment-notes">' . __( 'Your email address will not be published.', 'luxury' ) . ( $req ? $required_text : '' ) . '</p>',
		'comment_notes_after'  => '<p class="form-allowed-tags">' . sprintf( __( 'You may use these <abbr title="HyperText Markup Language">HTML</abbr> tags and attributes: %s' ), ' <code>' . allowed_tags() . '</code>' ) . '</p>',
		'id_form'              => 'commentform',
		'id_submit'            => 'submit',
		'title_reply'          => __( 'Leave a comment', 'luxury' ),
		'title_reply_to'       => __( 'Leave a comment to %s', 'luxury' ),
		'cancel_reply_link'    => __( 'Cancel comment', 'luxury' ),
		'label_submit'         => __( 'Post Comment', 'luxury' ),
	);

	$args = wp_parse_args( $args, apply_filters( 'comment_form_defaults', $defaults ) );

	?>
		<?php if ( comments_open() ) : ?>
			<?php do_action( 'comment_form_before' ); ?>
			<div id="respond">
				<p id="reply-title"><?php cancel_comment_reply_link( $args['cancel_reply_link'] ); ?></p>
				<?php if ( get_option( 'comment_registration' ) && !is_user_logged_in() ) : ?>
					<?php echo $args['must_log_in']; ?>
					<?php do_action( 'comment_form_must_log_in_after' ); ?>
				<?php else : ?>
					<form action="<?php echo site_url( '/wp-comments-post.php' ); ?>" method="post" id="<?php echo esc_attr( $args['id_form'] ); ?>">
						<?php do_action( 'comment_form_top' ); ?>
						<?php if ( is_user_logged_in() ) : ?>
							<?php echo apply_filters( 'comment_form_logged_in', $args['logged_in_as'], $commenter, $user_identity ); ?>
							<?php do_action( 'comment_form_logged_in_after', $commenter, $user_identity ); ?>
						<?php else : ?>
							<?php echo $args['comment_notes_before']; ?>
							<?php
							do_action( 'comment_form_before_fields' );
							foreach ( (array) $args['fields'] as $name => $field ) {
								echo apply_filters( "comment_form_field_{$name}", $field ) . "\n";
							}
							do_action( 'comment_form_after_fields' );
							?>
						<?php endif; ?>
						<?php echo apply_filters( 'comment_form_field_comment', $args['comment_field'] ); ?>
						<p class="form-submit">
							<input name="submit" type="submit" id="<?php echo esc_attr( $args['id_submit'] ); ?>" value="<?php echo esc_attr( $args['label_submit'] ); ?>" />
							<?php comment_id_fields( $post_id ); ?>
						</p>
						<?php echo $args['comment_notes_after']; ?>
						<?php do_action( 'comment_form', $post_id ); ?>
					</form>
				<?php endif; ?>
			</div><!-- #respond -->
			<?php do_action( 'comment_form_after' ); ?>
		<?php else : ?>
			<?php do_action( 'comment_form_comments_closed' ); ?>
		<?php endif; ?>
	<?php
}

/* End Comment Form Styling */