<?php
/*
luxury Theme Options
*/

function _admin_enqueue_scripts( $hook_suffix ) {
	wp_enqueue_style( 'luxury-theme-options', get_template_directory_uri() . '/inc/theme-options.css', false, '2012-07-03' );
}
add_action( 'admin_print_styles-appearance_page_theme_options', 'luxury_admin_enqueue_scripts' );

function luxury_theme_options_init() {
	register_setting(
		'luxury_options',
		'luxury_theme_options',
		'luxury_theme_options_validate'
	);

	add_settings_section(
		'general',
		'',
		'__return_false',
		'theme_options'
	);

	add_settings_section(
		'layout',
		'Default layout',
		'luxury_settings_field_layout',
		'theme_options',
		'general'
	);
}
add_action( 'admin_init', 'luxury_theme_options_init' );

function luxury_option_page_capability( $capability ) {
	return 'edit_theme_options';
}
add_filter( 'option_page_capability_luxury_options', 'luxury_option_page_capability' );

function luxury_theme_options_add_page() {
	$theme_page = add_theme_page(
		'Theme Options',
		'Theme Options',
		'edit_theme_options',
		'theme_options',
		'luxury_theme_options_render_page'
	);

	if ( ! $theme_page )
		return;
}
add_action( 'admin_menu', 'luxury_theme_options_add_page' );

function luxury_layouts() {
	$layout_options = array(
		'content-sidebar' => array(
			'value' => 'content-sidebar',
			'label' => 'Left content, right sidebar',
			'thumbnail' => get_template_directory_uri() . '/inc/images/content-sidebar.png'
		),
		'sidebar-content' => array(
			'value' => 'sidebar-content',
			'label' => 'Left sidebar, right content',
			'thumbnail' => get_template_directory_uri() . '/inc/images/sidebar-content.png'
		)
	);

	return apply_filters( 'luxury_layouts', $layout_options );
}

function luxury_get_default_theme_options() {
	$default_theme_options = array(
		'theme_layout' => 'content-sidebar'
	);

	return apply_filters( 'luxury_default_theme_options', $default_theme_options );
}

function luxury_get_theme_options() {
	return get_option( 'luxury_theme_options', luxury_get_default_theme_options() );
}

function luxury_settings_field_layout() {
	$options = luxury_get_theme_options();
	foreach ( luxury_layouts() as $layout ) {
		?>
		<div class="layout image-radio-option theme-layout">
		<label class="description">
			<input type="radio" name="luxury_theme_options[theme_layout]" value="<?php echo esc_attr( $layout['value'] ); ?>" <?php checked( $options['theme_layout'], $layout['value'] ); ?> />
			<span>
				<img src="<?php echo esc_url( $layout['thumbnail'] ); ?>" width="136" height="122" alt="" />
				<?php echo $layout['label']; ?>
			</span>
		</label>
		</div>
		<?php
	}
}

function luxury_theme_options_render_page() {
	?>
	<div class="wrap">
		<?php screen_icon(); ?>
		<?php $theme_name = function_exists( 'wp_get_theme' ) ? wp_get_theme() : get_current_theme(); ?>
		<h2><?php echo 'luxury Theme Options'; ?></h2>
		<?php settings_errors(); ?>

		<form method="post" action="options.php">
			<?php
				settings_fields( 'luxury_options' );
				do_settings_sections( 'theme_options' );
				submit_button();
			?>
		</form>
	</div>
<?php
}

function luxury_theme_options_validate( $input ) {
	$output = $defaults = luxury_get_default_theme_options();

	if ( isset( $input['theme_layout'] ) && array_key_exists( $input['theme_layout'], luxury_layouts() ) )
		$output['theme_layout'] = $input['theme_layout'];

	return apply_filters( 'luxury_theme_options_validate', $output, $input, $defaults );
}

function luxury_layout_classes( $existing_classes ) {
	$options = luxury_get_theme_options();
	$current_layout = $options['theme_layout'];

	if ( 'content-sidebar' == $current_layout )
		$classes[] = 'right-sidebar';
	elseif ( 'sidebar-content' == $current_layout )
		$classes[] = 'left-sidebar';
	else
		$classes[] = $current_layout;

	$classes = apply_filters( 'luxury_layout_classes', $classes, $current_layout );

	return array_merge( $existing_classes, $classes );
}
add_filter( 'body_class', 'luxury_layout_classes' );